import GoogleCalendar from './GoogleCalendar';
import GameSource from './GameSource';
import fs from 'fs';
import Ics from './Ics';
import express from 'express'
import env from 'dotenv';

env.config();



const CronJob = require('cron').CronJob;


class App {
  googleCalendar: GoogleCalendar;
  gameSource: GameSource;
  ics: Ics;
  googleToken: string;

  constructor() {
    this.googleCalendar = new GoogleCalendar();
    this.gameSource = new GameSource();
    this.ics = new Ics();
    
  }

  async init() {
    console.log("INIT APP")
    await this.googleCalendar.init();
  }

  async getNewGamesAndUpdateCalendar() {
    console.log("GET NEW GAMES AND UPDATE CALENDAR")
    const games = await this.gameSource.getGamesFromHaifa();
    this.googleCalendar.updateNewEvent(games);
  }
}

const app = new App();
console.log("Declaring Cron Job every day at 10:00")

const job = new CronJob(
  "0 10 * * *",  // every day at 10:00,
  async () => {
    console.log("Staring a new job")
    const outputFileLocation = 'public/maccabi-haifa-fc.ics';
    console.log("Getting games from Haifa")
    const games = await app.gameSource.getGamesFromHaifa();
    console.log("Generating ICS file")
    const icsEvents = app.ics.generateIcsOutputFromGames(games);
    console.log("Writing ICS file to " + outputFileLocation)
    fs.writeFileSync(outputFileLocation, icsEvents);
    console.log("Done")
  },
  null,
  true,
  'Asia/Jerusalem'
);

const webServer = express();
webServer.use(express.static('public'))

webServer.listen(process.env.PORT, () => {
  console.log('Example app listening on port '+process.env.PORT+'!')
})